diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index 78d3885..2c97918 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -338,11 +338,11 @@ of effort. We would like to acknowledge and thank the following people:
 "Richard Anderson       George Andrews         S.J. Atkins"
 "Henry Baker            Stephen Balzac         Yurij Baransky"
 "David R. Barton        Gerald Baumgartner     Gilbert Baumslag"
-"Michael Becker         Jay Belanger           David Bindel"
-"Fred Blair             Vladimir Bondarenko    Mark Botch"
-"Alexandre Bouyer       Peter A. Broadbery     Martin Brock"
-"Manuel Bronstein       Stephen Buchwald       Florian Bundschuh"
-"Luanne Burns           William Burge"
+"Michael Becker         Nelson H. F. Beebe     Jay Belanger"
+"David Bindel           Fred Blair             Vladimir Bondarenko"
+"Mark Botch             Alexandre Bouyer       Peter A. Broadbery"
+"Martin Brock           Manuel Bronstein       Stephen Buchwald"
+"Florian Bundschuh      Luanne Burns           William Burge"
 "Quentin Carpent        Robert Caviness        Bruce Char"
 "Ondrej Certik          Cheekai Chin           David V. Chudnovsky"
 "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil"
@@ -404,8 +404,8 @@ of effort. We would like to acknowledge and thank the following people:
 "Jonathan Steinbach     Fabio Stumbo           Christine Sundaresan"
 "Robert Sutor           Moss E. Sweedler       Eugene Surowitz"
 "Max Tegmark            James Thatcher         Balbir Thomas"
-"Mike Thomas            Dylan Thurston         Barry Trager"
-"Themos T. Tsikas"
+"Mike Thomas            Dylan Thurston         Steve Toleque"
+"Barry Trager           Themos T. Tsikas"
 "Gregory Vanuxem"
 "Bernhard Wall          Stephen Watt           Jaap Weel"
 "Juergen Weiss          M. Weller              Mark Wegman"
@@ -23853,6 +23853,7 @@ otherwise the new algebra won't be loaded by the interpreter when needed.
    (|BinaryTournament| . BTOURN)
    (|BinaryTree| . BTREE)
    (|Bits| . BITS)
+   (|BlasLevelOne| . BLAS1)
    (|Boolean| . BOOLEAN)
    (|CardinalNumber| . CARD)
    (|CartesianTensor| . CARTEN)
@@ -37348,6 +37349,28 @@ database format.
 
 @
 \chapter{Special Lisp Functions}
+\section{Axiom control structure macros}
+Axiom used various control structures in the boot code which are not
+available in Common Lisp. We write some macros here to make the boot
+to lisp translations easier to read.
+
+\defmacro{while}
+While the condition is true, repeat the body. 
+When the condition is false, return t.
+<<defmacro while>>=
+(defmacro while (condition &rest body)
+ `(loop (if (not ,condition) (return t)) ,@body))
+
+@
+
+\defmacro{whileWithResult}
+While the condition is true, repeat the body. 
+When the condition is false, return the result form's value.
+<<defmacro whileWithResult>>=
+(defmacro whileWithResult (condition result &rest body)
+ `(loop (if (not ,condition) ,@result) ,@body))
+
+@
 
 \section{Filename Handling}
 This code implements the Common Lisp pathname functions for
@@ -39538,6 +39561,8 @@ This needs to work off the internal exposure list, not the file.
 <<defmacro Rest>>
 <<defmacro startsId?>>
 <<defmacro truth-to-bit>>
+<<defmacro while>>
+<<defmacro whileWithResult>>
 
 <<defun abbQuery>>
 <<defun abbreviations>>
diff --git a/changelog b/changelog
index 0844dc4..216dc3e 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,8 @@
+20100401 tpd src/axiom-website/patches.html 20100401.02.tpd.patch
+20100401 tpd books/bookvol5 add Nelson Beebe and Steve Toleque
+20100401 tpd src/input/unittest2.input add Nelson Beebe and Steve Toleque
+20100401 tpd readme add Nelson Beebe and Steve Toleque to credits
+20100401 nhb Nelson H. F. Beebe <beebe@math.utah.edu>
 20100401 tpd src/axiom-website/patches.html 20100401.01.tpd.patch
 20100401 tpd faq FAQ 52: Who was User?
 20100331 tpd src/axiom-website/patches.html 20100331.01.tpd.patch
diff --git a/readme b/readme
index 71cc821..8c9ad91 100644
--- a/readme
+++ b/readme
@@ -192,11 +192,11 @@ at the axiom command prompt will prettyprint the list.
 "Richard Anderson       George Andrews         S.J. Atkins"
 "Henry Baker            Stephen Balzac         Yurij Baransky"
 "David R. Barton        Gerald Baumgartner     Gilbert Baumslag"
-"Michael Becker         Jay Belanger           David Bindel"
-"Fred Blair             Vladimir Bondarenko    Mark Botch"
-"Alexandre Bouyer       Peter A. Broadbery     Martin Brock"
-"Manuel Bronstein       Stephen Buchwald       Florian Bundschuh"
-"Luanne Burns           William Burge"
+"Michael Becker         Nelson H. F. Beebe     Jay Belanger"
+"David Bindel           Fred Blair             Vladimir Bondarenko"
+"Mark Botch             Alexandre Bouyer       Peter A. Broadbery"
+"Martin Brock           Manuel Bronstein       Stephen Buchwald"
+"Florian Bundschuh      Luanne Burns           William Burge"
 "Quentin Carpent        Robert Caviness        Bruce Char"
 "Ondrej Certik          Cheekai Chin           David V. Chudnovsky"
 "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil"
@@ -258,8 +258,8 @@ at the axiom command prompt will prettyprint the list.
 "Jonathan Steinbach     Fabio Stumbo           Christine Sundaresan"
 "Robert Sutor           Moss E. Sweedler       Eugene Surowitz"
 "Max Tegmark            James Thatcher         Balbir Thomas"
-"Mike Thomas            Dylan Thurston         Barry Trager"
-"Themos T. Tsikas"
+"Mike Thomas            Dylan Thurston         Steve Toleque"
+"Barry Trager           Themos T. Tsikas"
 "Gregory Vanuxem"
 "Bernhard Wall          Stephen Watt           Jaap Weel"
 "Juergen Weiss          M. Weller              Mark Wegman"
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 229bbbb..669aad9 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2601,5 +2601,7 @@ src/input/davenport.input examples from DST88 paper<br/>
 src/input/zimmer.input run the zimmerman test suite<br/>
 <a href="patches/20100401.01.tpd.patch">20100401.01.tpd.patch</a>
 faq FAQ 52: Who was User?<br/>
+<a href="patches/20100401.02.tpd.patch">20100401.02.tpd.patch</a>
+readme add Nelson Beebe and Steve Toleque to credits<br/>
  </body>
 </html>
diff --git a/src/input/unittest2.input.pamphlet b/src/input/unittest2.input.pamphlet
index 7d34690..4da4a85 100644
--- a/src/input/unittest2.input.pamphlet
+++ b/src/input/unittest2.input.pamphlet
@@ -93,7 +93,7 @@ Unit test the user level commands
 --S 13 of 236
 )lisp (identity credits)
 --R 
---RValue = ("An alphabetical listing of contributors to AXIOM:" "Cyril Alberga          Roy Adler              Christian Aistleitner" "Richard Anderson       George Andrews         S.J. Atkins" "Henry Baker            Stephen Balzac         Yurij Baransky" "David R. Barton        Gerald Baumgartner     Gilbert Baumslag" "Michael Becker         Jay Belanger           David Bindel" "Fred Blair             Vladimir Bondarenko    Mark Botch" "Alexandre Bouyer       Peter A. Broadbery     Martin Brock" "Manuel Bronstein       Stephen Buchwald       Florian Bundschuh" "Luanne Burns           William Burge" "Quentin Carpent        Robert Caviness        Bruce Char" "Ondrej Certik          Cheekai Chin           David V. Chudnovsky" "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil" "Don Coppersmith        George Corliss         Robert Corless" "Gary Cornell           Meino Cramer           Claire Di Crescenzo" "David Cyganski" "Nathaniel Daly         Timothy Daly Sr.       Timothy Daly Jr." "James H. Davenport     Didier Deshommes       Michael Dewar" "Jean Della Dora        Gabriel Dos Reis       Claire DiCrescendo" "Sam Dooley             Lionel Ducos           Lee Duhem" "Martin Dunstan         Brian Dupee            Dominique Duval" "Robert Edwards         Heow Eide-Goodman      Lars Erickson" "Richard Fateman        Bertfried Fauser       Stuart Feldman" "John Fletcher          Brian Ford             Albrecht Fortenbacher" "George Frances         Constantine Frangos    Timothy Freeman" "Korrinn Fu" "Marc Gaetano           Rudiger Gebauer        Kathy Gerber" "Patricia Gianni        Samantha Goldrich      Holger Gollan" "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler" "Johannes Grabmeier     Matt Grayson           Klaus Ebbe Grue" "James Griesmer         Vladimir Grinberg      Oswald Gschnitzer" "Jocelyn Guidry" "Steve Hague            Satoshi Hamaguchi      Mike Hansen" "Richard Harke          Vilya Harvey           Martin Hassner" "Arthur S. Hathaway     Dan Hatton             Waldek Hebisch" "Karl Hegbloom          Ralf Hemmecke          Henderson" "Antoine Hersen         Gernot Hueber" "Pietro Iglio" "Alejandro Jakubi       Richard Jenks" "Kai Kaminski           Grant Keady            Tony Kennedy" "Ted Kosan              Paul Kosinski          Klaus Kusche" "Bernhard Kutzler" "Tim Lahey              Larry Lambe            Franz Lehner" "Frederic Lehobey       Michel Levaud          Howard Levy" "Liu Xiaojun            Rudiger Loos           Michael Lucks" "Richard Luczak" "Camm Maguire           Francois Maltey        Alasdair McAndrew" "Bob McElrath           Michael McGettrick     Ian Meikle" "David Mentre           Victor S. Miller       Gerard Milmeister" "Mohammed Mobarak       H. Michael Moeller     Michael Monagan" "Marc Moreno-Maza       Scott Morrison         Joel Moses" "Mark Murray" "William Naylor         C. Andrew Neff         John Nelder" "Godfrey Nolan          Arthur Norman          Jinzhong Niu" "Michael O'Connor       Summat Oemrawsingh     Kostas Oikonomou" "Humberto Ortiz-Zuazaga" "Julian A. Padget       Bill Page              Susan Pelzel" "Michel Petitot         Didier Pinchon         Ayal Pinkus" "Jose Alfredo Portes" "Claude Quitte" "Arthur C. Ralfs        Norman Ramsey          Anatoly Raportirenko" "Michael Richardson     Renaud Rioboo          Jean Rivlin" "Nicolas Robidoux       Simon Robinson         Raymond Rogers" "Michael Rothstein      Martin Rubey" "Philip Santas          Alfred Scheerhorn      William Schelter" "Gerhard Schneider      Martin Schoenert       Marshall Schor" "Frithjof Schulze       Fritz Schwarz          Steven Segletes" "Nick Simicich          William Sit            Elena Smirnova" "Jonathan Steinbach     Fabio Stumbo           Christine Sundaresan" "Robert Sutor           Moss E. Sweedler       Eugene Surowitz" "Max Tegmark            James Thatcher         Balbir Thomas" "Mike Thomas            Dylan Thurston         Barry Trager" "Themos T. Tsikas" "Gregory Vanuxem" "Bernhard Wall          Stephen Watt           Jaap Weel" "Juergen Weiss          M. Weller              Mark Wegman" "James Wen              Thorsten Werther       Michael Wester" "John M. Wiley          Berhard Will           Clifton J. Williamson" "Stephen Wilson         Shmuel Winograd        Robert Wisbauer" "Sandra Wityak          Waldemar Wiwianka      Knut Wolf" "Clifford Yapp          David Yun" "Vadim Zhytnikov        Richard Zippel         Evelyn Zoernack" "Bruno Zuercher         Dan Zwillinger")
+--RValue = ("An alphabetical listing of contributors to AXIOM:" "Cyril Alberga          Roy Adler              Christian Aistleitner" "Richard Anderson       George Andrews         S.J. Atkins" "Henry Baker            Stephen Balzac         Yurij Baransky" "David R. Barton        Gerald Baumgartner     Gilbert Baumslag" "Michael Becker         Nelson H. F. Beebe     Jay Belanger" "David Bindel           Fred Blair             Vladimir Bondarenko" "Mark Botch             Alexandre Bouyer       Peter A. Broadbery" "Martin Brock           Manuel Bronstein       Stephen Buchwald" "Florian Bundschuh      Luanne Burns           William Burge" "Quentin Carpent        Robert Caviness        Bruce Char" "Ondrej Certik          Cheekai Chin           David V. Chudnovsky" "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil" "Don Coppersmith        George Corliss         Robert Corless" "Gary Cornell           Meino Cramer           Claire Di Crescenzo" "David Cyganski" "Nathaniel Daly         Timothy Daly Sr.       Timothy Daly Jr." "James H. Davenport     Didier Deshommes       Michael Dewar" "Jean Della Dora        Gabriel Dos Reis       Claire DiCrescendo" "Sam Dooley             Lionel Ducos           Lee Duhem" "Martin Dunstan         Brian Dupee            Dominique Duval" "Robert Edwards         Heow Eide-Goodman      Lars Erickson" "Richard Fateman        Bertfried Fauser       Stuart Feldman" "John Fletcher          Brian Ford             Albrecht Fortenbacher" "George Frances         Constantine Frangos    Timothy Freeman" "Korrinn Fu" "Marc Gaetano           Rudiger Gebauer        Kathy Gerber" "Patricia Gianni        Samantha Goldrich      Holger Gollan" "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler" "Johannes Grabmeier     Matt Grayson           Klaus Ebbe Grue" "James Griesmer         Vladimir Grinberg      Oswald Gschnitzer" "Jocelyn Guidry" "Steve Hague            Satoshi Hamaguchi      Mike Hansen" "Richard Harke          Vilya Harvey           Martin Hassner" "Arthur S. Hathaway     Dan Hatton             Waldek Hebisch" "Karl Hegbloom          Ralf Hemmecke          Henderson" "Antoine Hersen         Gernot Hueber" "Pietro Iglio" "Alejandro Jakubi       Richard Jenks" "Kai Kaminski           Grant Keady            Tony Kennedy" "Ted Kosan              Paul Kosinski          Klaus Kusche" "Bernhard Kutzler" "Tim Lahey              Larry Lambe            Franz Lehner" "Frederic Lehobey       Michel Levaud          Howard Levy" "Liu Xiaojun            Rudiger Loos           Michael Lucks" "Richard Luczak" "Camm Maguire           Francois Maltey        Alasdair McAndrew" "Bob McElrath           Michael McGettrick     Ian Meikle" "David Mentre           Victor S. Miller       Gerard Milmeister" "Mohammed Mobarak       H. Michael Moeller     Michael Monagan" "Marc Moreno-Maza       Scott Morrison         Joel Moses" "Mark Murray" "William Naylor         C. Andrew Neff         John Nelder" "Godfrey Nolan          Arthur Norman          Jinzhong Niu" "Michael O'Connor       Summat Oemrawsingh     Kostas Oikonomou" "Humberto Ortiz-Zuazaga" "Julian A. Padget       Bill Page              Susan Pelzel" "Michel Petitot         Didier Pinchon         Ayal Pinkus" "Jose Alfredo Portes" "Claude Quitte" "Arthur C. Ralfs        Norman Ramsey          Anatoly Raportirenko" "Michael Richardson     Renaud Rioboo          Jean Rivlin" "Nicolas Robidoux       Simon Robinson         Raymond Rogers" "Michael Rothstein      Martin Rubey" "Philip Santas          Alfred Scheerhorn      William Schelter" "Gerhard Schneider      Martin Schoenert       Marshall Schor" "Frithjof Schulze       Fritz Schwarz          Steven Segletes" "Nick Simicich          William Sit            Elena Smirnova" "Jonathan Steinbach     Fabio Stumbo           Christine Sundaresan" "Robert Sutor           Moss E. Sweedler       Eugene Surowitz" "Max Tegmark            James Thatcher         Balbir Thomas" "Mike Thomas            Dylan Thurston         Steve Toleque" "Barry Trager           Themos T. Tsikas" "Gregory Vanuxem" "Bernhard Wall          Stephen Watt           Jaap Weel" "Juergen Weiss          M. Weller              Mark Wegman" "James Wen              Thorsten Werther       Michael Wester" "John M. Wiley          Berhard Will           Clifton J. Williamson" "Stephen Wilson         Shmuel Winograd        Robert Wisbauer" "Sandra Wityak          Waldemar Wiwianka      Knut Wolf" "Clifford Yapp          David Yun" "Vadim Zhytnikov        Richard Zippel         Evelyn Zoernack" "Bruno Zuercher         Dan Zwillinger")
 --E 13
 
 --S 14 of 236
